[![Tests](https://github.com/Electrostatics/mmcif_pdbx/workflows/Tests/badge.svg)](https://github.com/Electrostatics/mmcif_pdbx/actions?query=workflow%3ATests)
[![codecov](https://codecov.io/gh/Electrostatics/mmcif_pdbx/branch/master/graph/badge.svg)](https://codecov.io/gh/Electrostatics/mmcif_pdbx)

# PDBx/mmCIF Dictionary Resources

This is yet another PyPI package for http://mmcif.wwpdb.org/pdbx-mmcif-home-page.html.
Others include:

* https://pypi.org/project/mmcif/ and https://pypi.org/project/mmcif.utils/ -- the author of this package is John Westbrook and the homepage is http://mmcif.wwpdb.org/, which suggests it may be the canonical version.
Unfortunately, the PyPI package does not compile on many platforms (e.g., Windows 10 with Python 3.8) and does not provide a repository for pull requests to fix the problems.
* https://pypi.org/project/pdbx-mmcif/ -- this package includes very little documentation and the homepage https://github.com/ostrokach/pdbx is the fork of another repo, which does not inspire confidence in long-term maintenance and bug fixes.

## Origin of this software
All of the code in this repository is based on http://mmcif.wwpdb.org/.
Specifically, this code is directly derived from http://mmcif.wwpdb.org/docs/sw-examples/python/src/pdbx.tar.gz linked from http://mmcif.wwpdb.org/docs/sw-examples/python/html/.

See http://mmcif.wwpdb.org/docs/sw-examples/python/html/ for more information about this package, including examples.
